
--
-- Polynom
-- Copyright 2024 Code Siren, LLC
-- SQLite Update Script
-- June 18, 2024
-- Version 1.1.0
--


--
-- Channel
--
ALTER TABLE channel ADD COLUMN category TEXT;
ALTER TABLE channel ADD COLUMN color INTEGER;
ALTER TABLE channel ADD COLUMN rank INTEGER;


--
-- Note Text
--
DROP TABLE IF EXISTS note_text;
CREATE TABLE IF NOT EXISTS note_text
(
	-- Primary Keys
	id INTEGER PRIMARY KEY AUTOINCREMENT,

	-- Foreign Keys
	owner_id INTEGER NOT NULL,
	user_id INTEGER,

	-- Fields
	cipher_key BLOB,
	cipher_text BLOB,
	created INTEGER NOT NULL,
	modified INTEGER,
	nonce INTEGER,
	signature BLOB,
	text TEXT,

	-- Constraints
	FOREIGN KEY(owner_id) REFERENCES user(id) ON DELETE CASCADE,
	FOREIGN KEY(user_id) REFERENCES user(id) ON DELETE CASCADE,
	UNIQUE(nonce, owner_id)
);

-- Indices
DROP INDEX IF EXISTS idx_note_text_owner_id;
CREATE INDEX idx_note_text_owner_id ON note_text(owner_id);

DROP INDEX IF EXISTS idx_note_text_user_id;
CREATE INDEX idx_note_text_user_id ON note_text(user_id);

DROP INDEX IF EXISTS idx_note_text_created;
CREATE INDEX idx_note_text_created ON note_text(created);

DROP INDEX IF EXISTS idx_note_text_nonce;
CREATE INDEX idx_note_text_nonce ON note_text(nonce);


--
-- Note Text File
--
DROP TABLE IF EXISTS note_text_file;
CREATE TABLE IF NOT EXISTS note_text_file
(
	-- Primary Keys
	id INTEGER PRIMARY KEY AUTOINCREMENT,

	-- Foreign Keys
	owner_id INTEGER NOT NULL,
	text_id INTEGER NOT NULL,
	user_id INTEGER,

	-- Fields
	animation BOOLEAN,
	cipher_key BLOB,
	created INTEGER NOT NULL,
	hash BLOB NOT NULL,
	height INTEGER,
	image_hash BLOB,
	image_height INTEGER,
	image_size INTEGER,
	image_width INTEGER,
	modified INTEGER,
	name TEXT NOT NULL,	-- Encrypted
	nonce INTEGER,
	size INTEGER,
	width INTEGER,

	-- Constraints
	FOREIGN KEY(owner_id) REFERENCES user(id) ON DELETE CASCADE,
	FOREIGN KEY(text_id) REFERENCES note_text(id) ON DELETE CASCADE,
	FOREIGN KEY(user_id) REFERENCES user(id) ON DELETE CASCADE
);

-- Indices
DROP INDEX IF EXISTS idx_note_text_file_owner_id;
CREATE INDEX idx_note_text_file_owner_id ON note_text_file(owner_id);

DROP INDEX IF EXISTS idx_note_text_file_text_id;
CREATE INDEX idx_note_text_file_text_id ON note_text_file(text_id);

DROP INDEX IF EXISTS idx_note_text_file_user_id;
CREATE INDEX idx_note_text_file_user_id ON note_text_file(user_id);

DROP INDEX IF EXISTS idx_note_text_file_created;
CREATE INDEX idx_note_text_file_created ON note_text_file(created);

DROP INDEX IF EXISTS idx_note_text_file_hash;
CREATE INDEX idx_note_text_file_hash ON note_text_file(hash);

DROP INDEX IF EXISTS idx_note_text_file_name;
CREATE INDEX idx_note_text_file_name ON note_text_file(name collate nocase);

DROP INDEX IF EXISTS idx_note_text_file_nonce;
CREATE INDEX idx_note_text_file_nonce ON note_text_file(nonce);


--
-- Note Text Mention
--
DROP TABLE IF EXISTS note_text_mention;
CREATE TABLE IF NOT EXISTS note_text_mention
(
	-- Primary Keys
	id INTEGER PRIMARY KEY AUTOINCREMENT,

	-- Foreign Keys
	owner_id INTEGER NOT NULL,
	text_id INTEGER NOT NULL,
	user_id INTEGER NOT NULL,

	-- Fields
	position INTEGER NOT NULL,

	-- Constraints
	FOREIGN KEY(owner_id) REFERENCES user(id) ON DELETE CASCADE,
	FOREIGN KEY(text_id) REFERENCES note_text(id) ON DELETE CASCADE,
	FOREIGN KEY(user_id) REFERENCES user(id) ON DELETE CASCADE
);

-- Indices
DROP INDEX IF EXISTS idx_note_text_mention_owner_id;
CREATE INDEX idx_note_text_mention_owner_id ON note_text_mention(owner_id);

DROP INDEX IF EXISTS idx_note_text_mention_text_id;
CREATE INDEX idx_note_text_mention_text_id ON note_text_mention(text_id);

DROP INDEX IF EXISTS idx_note_text_mention_user_id;
CREATE INDEX idx_note_text_mention_user_id ON note_text_mention(user_id);


--
-- Room
--
ALTER TABLE room ADD COLUMN category TEXT;
ALTER TABLE room ADD COLUMN color INTEGER;
ALTER TABLE room ADD COLUMN rank INTEGER;


--
-- User
--
ALTER TABLE user ADD COLUMN online INTEGER;
